@@ -11,6 +11,7 @@
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
 
+import copy
 import math
 from typing import List, Optional, Sequence, Union
 
@@ -87,6 +88,16 @@ class AngledGate(Gate, Parameterizable):
         """
         raise NotImplementedError
 
+    def adjoint(self) -> List[Gate]:
+        """Returns the adjoint of this gate as a singleton list.
+
+        Returns:
+            List[Gate]: A list containing the gate with negated angle.
+        """
+        new = copy.copy(self)
+        new._parameters = [-angle for angle in self._parameters]
+        return [new]
+
     def __eq__(self, other):
         if isinstance(other, AngledGate):
             if isinstance(self.angle, FreeParameterExpression):
