@@ -144,10 +144,9 @@ class Circuit:
         return self._moments.depth
 
     @property
-    def instructions(self) -> Iterable[Instruction]:
+    def instructions(self) -> List[Instruction]:
         """Iterable[Instruction]: Get an `iterable` of instructions in the circuit."""
-
-        return self._moments.values()
+        return list(self._moments.values())
 
     @property
     def result_types(self) -> List[ResultType]:
@@ -1031,6 +1030,22 @@ class Circuit:
 
         return self
 
+    def adjoint(self) -> Circuit:
+        """Returns the adjoint of this circuit.
+
+        This is the adjoint of every instruction of the circuit, in reverse order. Result types,
+        and consequently basis rotations will stay in the same order at the end of the circuit.
+
+        Returns:
+            Circuit: The adjoint of the circuit.
+        """
+        circ = Circuit()
+        for instr in reversed(self.instructions):
+            circ.add(instr.adjoint())
+        for result_type in self._result_types:
+            circ.add_result_type(result_type)
+        return circ
+
     def diagram(self, circuit_diagram_class=AsciiCircuitDiagram) -> str:
         """
         Get a diagram for the current circuit.
@@ -1050,9 +1065,9 @@ class Circuit:
         If the circuit is sent over the wire, this method is called before it is sent.
 
         Returns:
-            (Program): An AWS quantum circuit description program in JSON format.
+            Program: A Braket quantum circuit description program in JSON format.
         """
-        ir_instructions = [instr.to_ir() for instr in self.instructions]
+        ir_instructions = [instruction.to_ir() for instruction in self.instructions]
         ir_results = [result_type.to_ir() for result_type in self.result_types]
         ir_basis_rotation_instructions = [
             instr.to_ir() for instr in self.basis_rotation_instructions
@@ -1192,10 +1207,10 @@ class Circuit:
 
     def __repr__(self) -> str:
         if not self.result_types:
-            return f"Circuit('instructions': {list(self.instructions)})"
+            return f"Circuit('instructions': {self.instructions})"
         else:
             return (
-                f"Circuit('instructions': {list(self.instructions)}"
+                f"Circuit('instructions': {self.instructions}"
                 + f", 'result_types': {self.result_types})"
             )
 
@@ -1205,8 +1220,7 @@ class Circuit:
     def __eq__(self, other):
         if isinstance(other, Circuit):
             return (
-                list(self.instructions) == list(other.instructions)
-                and self.result_types == other.result_types
+                self.instructions == other.instructions and self.result_types == other.result_types
             )
         return NotImplemented
 
