@@ -11,7 +11,7 @@
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
 
-from typing import Iterable, Union
+from typing import Iterable, List, Union
 
 import numpy as np
 from sympy import Float
@@ -39,6 +39,7 @@ To add a new gate:
     3. Register the class with the `Gate` class via `Gate.register_gate()`.
 """
 
+
 # Single qubit gates #
 
 
@@ -48,6 +49,9 @@ class H(Gate):
     def __init__(self):
         super().__init__(qubit_count=None, ascii_symbols=["H"])
 
+    def adjoint(self) -> List[Gate]:
+        return [H()]
+
     def to_ir(self, target: QubitSet):
         return ir.H.construct(target=target[0])
 
@@ -85,6 +89,9 @@ class I(Gate):  # noqa: E742, E261
     def __init__(self):
         super().__init__(qubit_count=None, ascii_symbols=["I"])
 
+    def adjoint(self) -> List[Gate]:
+        return [I()]
+
     def to_ir(self, target: QubitSet):
         return ir.I.construct(target=target[0])
 
@@ -122,6 +129,9 @@ class X(Gate):
     def __init__(self):
         super().__init__(qubit_count=None, ascii_symbols=["X"])
 
+    def adjoint(self) -> List[Gate]:
+        return [X()]
+
     def to_ir(self, target: QubitSet):
         return ir.X.construct(target=target[0])
 
@@ -159,6 +169,9 @@ class Y(Gate):
     def __init__(self):
         super().__init__(qubit_count=None, ascii_symbols=["Y"])
 
+    def adjoint(self) -> List[Gate]:
+        return [Y()]
+
     def to_ir(self, target: QubitSet):
         return ir.Y.construct(target=target[0])
 
@@ -196,6 +209,9 @@ class Z(Gate):
     def __init__(self):
         super().__init__(qubit_count=None, ascii_symbols=["Z"])
 
+    def adjoint(self) -> List[Gate]:
+        return [Z()]
+
     def to_ir(self, target: QubitSet):
         return ir.Z.construct(target=target[0])
 
@@ -233,11 +249,13 @@ class S(Gate):
     def __init__(self):
         super().__init__(qubit_count=None, ascii_symbols=["S"])
 
+    def adjoint(self) -> List[Gate]:
+        return [Si()]
+
     def to_ir(self, target: QubitSet):
         return ir.S.construct(target=target[0])
 
     def to_matrix(self) -> np.ndarray:
-
         return np.array([[1.0, 0.0], [0.0, 1.0j]], dtype=complex)
 
     @staticmethod
@@ -271,6 +289,9 @@ class Si(Gate):
     def __init__(self):
         super().__init__(qubit_count=None, ascii_symbols=["Si"])
 
+    def adjoint(self) -> List[Gate]:
+        return [S()]
+
     def to_ir(self, target: QubitSet):
         return ir.Si.construct(target=target[0])
 
@@ -308,6 +329,9 @@ class T(Gate):
     def __init__(self):
         super().__init__(qubit_count=None, ascii_symbols=["T"])
 
+    def adjoint(self) -> List[Gate]:
+        return [Ti()]
+
     def to_ir(self, target: QubitSet):
         return ir.T.construct(target=target[0])
 
@@ -345,6 +369,9 @@ class Ti(Gate):
     def __init__(self):
         super().__init__(qubit_count=None, ascii_symbols=["Ti"])
 
+    def adjoint(self) -> List[Gate]:
+        return [T()]
+
     def to_ir(self, target: QubitSet):
         return ir.Ti.construct(target=target[0])
 
@@ -382,6 +409,9 @@ class V(Gate):
     def __init__(self):
         super().__init__(qubit_count=None, ascii_symbols=["V"])
 
+    def adjoint(self) -> List[Gate]:
+        return [Vi()]
+
     def to_ir(self, target: QubitSet):
         return ir.V.construct(target=target[0])
 
@@ -419,6 +449,9 @@ class Vi(Gate):
     def __init__(self):
         super().__init__(qubit_count=None, ascii_symbols=["Vi"])
 
+    def adjoint(self) -> List[Gate]:
+        return [V()]
+
     def to_ir(self, target: QubitSet):
         return ir.Vi.construct(target=target[0])
 
@@ -704,6 +737,9 @@ class CNot(Gate):
     def __init__(self):
         super().__init__(qubit_count=None, ascii_symbols=["C", "X"])
 
+    def adjoint(self) -> List[Gate]:
+        return [CNot()]
+
     def to_ir(self, target: QubitSet):
         return ir.CNot.construct(control=target[0], target=target[1])
 
@@ -749,6 +785,9 @@ class Swap(Gate):
     def __init__(self):
         super().__init__(qubit_count=None, ascii_symbols=["SWAP", "SWAP"])
 
+    def adjoint(self) -> List[Gate]:
+        return [Swap()]
+
     def to_ir(self, target: QubitSet):
         return ir.Swap.construct(targets=[target[0], target[1]])
 
@@ -794,6 +833,9 @@ class ISwap(Gate):
     def __init__(self):
         super().__init__(qubit_count=None, ascii_symbols=["ISWAP", "ISWAP"])
 
+    def adjoint(self) -> List[Gate]:
+        return [self, self, self]
+
     def to_ir(self, target: QubitSet):
         return ir.ISwap.construct(targets=[target[0], target[1]])
 
@@ -1235,6 +1277,9 @@ class CV(Gate):
     def __init__(self):
         super().__init__(qubit_count=None, ascii_symbols=["C", "V"])
 
+    def adjoint(self) -> List[Gate]:
+        return [self, self, self]
+
     def to_ir(self, target: QubitSet):
         return ir.CV.construct(control=target[0], target=target[1])
 
@@ -1280,6 +1325,9 @@ class CY(Gate):
     def __init__(self):
         super().__init__(qubit_count=None, ascii_symbols=["C", "Y"])
 
+    def adjoint(self) -> List[Gate]:
+        return [CY()]
+
     def to_ir(self, target: QubitSet):
         return ir.CY.construct(control=target[0], target=target[1])
 
@@ -1325,6 +1373,9 @@ class CZ(Gate):
     def __init__(self):
         super().__init__(qubit_count=None, ascii_symbols=["C", "Z"])
 
+    def adjoint(self) -> List[Gate]:
+        return [CZ()]
+
     def to_ir(self, target: QubitSet):
         return ir.CZ.construct(control=target[0], target=target[1])
 
@@ -1362,6 +1413,9 @@ class ECR(Gate):
     def __init__(self):
         super().__init__(qubit_count=None, ascii_symbols=["ECR", "ECR"])
 
+    def adjoint(self) -> List[Gate]:
+        return [ECR()]
+
     def to_ir(self, target: QubitSet):
         return ir.ECR.construct(targets=[target[0], target[1]])
 
@@ -1638,6 +1692,9 @@ class CCNot(Gate):
     def __init__(self):
         super().__init__(qubit_count=None, ascii_symbols=["C", "C", "X"])
 
+    def adjoint(self) -> List[Gate]:
+        return [CCNot()]
+
     def to_ir(self, target: QubitSet):
         return ir.CCNot.construct(controls=[target[0], target[1]], target=target[2])
 
@@ -1688,6 +1745,9 @@ class CSwap(Gate):
     def __init__(self):
         super().__init__(qubit_count=None, ascii_symbols=["C", "SWAP", "SWAP"])
 
+    def adjoint(self) -> List[Gate]:
+        return [CSwap()]
+
     def to_ir(self, target: QubitSet):
         return ir.CSwap.construct(control=target[0], targets=[target[1], target[2]])
 
@@ -1759,6 +1819,9 @@ class Unitary(Gate):
     def to_matrix(self):
         return np.array(self._matrix)
 
+    def adjoint(self) -> List[Gate]:
+        return [Unitary(self._matrix.conj().T, display_name=f"({self.ascii_symbols})^†")]
+
     def to_ir(self, target: QubitSet):
         return ir.Unitary.construct(
             targets=[qubit for qubit in target],
