@@ -11,7 +11,8 @@
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
 
-from typing import Iterable
+import itertools
+from typing import Dict, Iterable
 
 import numpy as np
 
@@ -21,6 +22,7 @@ from braket.circuits.instruction import Instruction
 from braket.circuits.noise import (
     DampingNoise,
     GeneralizedAmplitudeDampingNoise,
+    MultiQubitPauliNoise,
     Noise,
     PauliNoise,
     SingleProbabilisticNoise,
@@ -552,6 +554,135 @@ class TwoQubitDephasing(SingleProbabilisticNoise_34):
 Noise.register_noise(TwoQubitDephasing)
 
 
+class TwoQubitPauliChannel(MultiQubitPauliNoise):
+    """Two-Qubit Pauli noise channel which transforms a
+        density matrix :math:`\\rho` according to:
+
+    .. math::
+        \\rho \\Rightarrow (1-p) \\rho +
+            p_{IX} IX \\rho IX^{\\dagger} +
+            p_{IY} IY \\rho IY^{\\dagger} +
+            p_{IZ} IZ \\rho IZ^{\\dagger} +
+            p_{XI} XI \\rho XI^{\\dagger} +
+            p_{XX} XX \\rho XX^{\\dagger} +
+            p_{XY} XY \\rho XY^{\\dagger} +
+            p_{XZ} XZ \\rho XZ^{\\dagger} +
+            p_{YI} YI \\rho YI^{\\dagger} +
+            p_{YX} YX \\rho YX^{\\dagger} +
+            p_{YY} YY \\rho YY^{\\dagger} +
+            p_{YZ} YZ \\rho YZ^{\\dagger} +
+            p_{ZI} ZI \\rho ZI^{\\dagger} +
+            p_{ZX} ZX \\rho ZX^{\\dagger} +
+            p_{ZY} ZY \\rho ZY^{\\dagger} +
+            p_{ZZ} ZZ \\rho ZZ^{\\dagger})
+    where
+
+    .. math::
+        I = \\left(
+                \\begin{matrix}
+                    1 & 0 \\\\
+                    0 & 1
+                \\end{matrix}
+            \\right)
+
+        X = \\left(
+                \\begin{matrix}
+                    0 & 1 \\\\
+                    1 & 0
+                \\end{matrix}
+            \\right)
+
+        Y = \\left(
+                \\begin{matrix}
+                    0 & -i \\\\
+                    i &  0
+                \\end{matrix}
+            \\right)
+
+        Z = \\left(
+                \\begin{matrix}
+                    1 & 0 \\\\
+                    0 & -1
+                \\end{matrix}
+            \\right)
+
+        p = \\text{sum of all probabilities}
+
+    This noise channel is shown as `PC_2({"pauli_string": probability})` in circuit diagrams.
+    """
+
+    _paulis = {
+        "I": np.array([[1.0, 0.0], [0.0, 1.0]], dtype=complex),
+        "X": np.array([[0.0, 1.0], [1.0, 0.0]], dtype=complex),
+        "Y": np.array([[0.0, -1.0j], [1.0j, 0.0]], dtype=complex),
+        "Z": np.array([[1.0, 0.0], [0.0, -1.0]], dtype=complex),
+    }
+    _tensor_products_strings = itertools.product(_paulis.keys(), repeat=2)
+    _names_list = ["".join(x) for x in _tensor_products_strings]
+
+    def __init__(self, probabilities: Dict[str, float]):
+        super().__init__(
+            probabilities=probabilities,
+            qubit_count=None,
+            ascii_symbols=[
+                f"PC2({probabilities})",
+                f"PC2({probabilities})",
+            ],
+        )
+
+        total_prob = sum(self.probabilities.values())
+
+        K_list = [np.sqrt(1 - total_prob) * np.identity(4)]  # "II" element
+        for pstring in self._names_list[1:]:  # ignore "II"
+            if pstring in self.probabilities:
+                mat = np.sqrt(self.probabilities[pstring]) * np.kron(
+                    self._paulis[pstring[0]], self._paulis[pstring[1]]
+                )
+                K_list.append(mat)
+            else:
+                K_list.append(np.zeros((4, 4)))
+        self._matrix = K_list
+
+    def to_ir(self, target: QubitSet):
+        return ir.MultiQubitPauliChannel.construct(
+            targets=[target[0], target[1]], probabilities=self.probabilities
+        )
+
+    def to_matrix(self) -> Iterable[np.ndarray]:
+        return self._matrix
+
+    @staticmethod
+    def fixed_qubit_count() -> int:
+        return 2
+
+    @staticmethod
+    @circuit.subroutine(register=True)
+    def two_qubit_pauli_channel(
+        target1: QubitInput, target2: QubitInput, probabilities: Dict[str, float]
+    ) -> Iterable[Instruction]:
+        """Registers this function into the circuit class.
+
+        Args:
+            target (Qubit, int, or iterable of Qubit / int): Target qubits
+            probability (float): Probability of two-qubit Pauli channel.
+
+        Returns:
+            Iterable[Instruction]: `Iterable` of Depolarizing instructions.
+
+        Examples:
+            >>> circ = Circuit().two_qubit_pauli_channel(0, 1, {"XX": 0.1})
+        """
+        return [
+            Instruction(
+                Noise.TwoQubitPauliChannel(probabilities=probabilities),
+                target=[target1, target2],
+            )
+        ]
+
+
+Noise.register_noise(TwoQubitPauliChannel)
+
+
 class AmplitudeDamping(DampingNoise):
     """AmplitudeDamping noise channel which transforms a density matrix :math:`\\rho` according to:
 
@@ -789,7 +920,7 @@ class Kraus(Noise):
 
     Args:
         matrices (Iterable[np.array]): A list of matrices that define a noise
-            channel. These matrices need to satisify the requirement of CPTP map.
+            channel. These matrices need to satisfy the requirement of CPTP map.
         display_name (str): Name to be used for an instance of this general noise
             channel for circuit diagrams. Defaults to `KR`.
 
@@ -797,7 +928,7 @@ class Kraus(Noise):
         ValueError: If any matrix in `matrices` is not a two-dimensional square
             matrix,
             or has a dimension length which is not a positive exponent of 2,
-            or the `matrices` do not satisify CPTP condition.
+            or the `matrices` do not satisfy CPTP condition.
     """
 
     def __init__(self, matrices: Iterable[np.ndarray], display_name: str = "KR"):
