@@ -31,17 +31,14 @@ def test_empty_circuit():
 def test_one_gate_one_qubit():
     circ = Circuit().h(0)
     expected = ("T  : |0|", "        ", "q0 : -H-", "", "T  : |0|")
-    expected = "\n".join(expected)
-    assert AsciiCircuitDiagram.build_diagram(circ) == expected
+    _assert_correct_diagram(circ, expected)
 
 
 def test_one_gate_one_qubit_rotation():
     circ = Circuit().rx(angle=3.14, target=0)
     # Column formats to length of the gate plus the ascii representation for the angle.
     expected = ("T  : |   0    |", "               ", "q0 : -Rx(3.14)-", "", "T  : |   0    |")
-    expected = "\n".join(expected)
-
-    assert AsciiCircuitDiagram.build_diagram(circ) == expected
+    _assert_correct_diagram(circ, expected)
 
 
 def test_one_gate_one_qubit_rotation_with_parameter():
@@ -57,8 +54,7 @@ def test_one_gate_one_qubit_rotation_with_parameter():
         "",
         "Unassigned parameters: {theta}.",
     )
-    expected = "\n".join(expected)
-    assert AsciiCircuitDiagram.build_diagram(circ) == expected
+    _assert_correct_diagram(circ, expected)
 
 
 def test_one_gate_one_qubit_rotation_with_unicode():
@@ -74,8 +70,7 @@ def test_one_gate_one_qubit_rotation_with_unicode():
         "",
         "Unassigned parameters: {θ}.",
     )
-    expected = "\n".join(expected)
-    assert AsciiCircuitDiagram.build_diagram(circ) == expected
+    _assert_correct_diagram(circ, expected)
 
 
 def test_one_gate_one_qubit_rotation_with_parameter_assigned():
@@ -90,9 +85,7 @@ def test_one_gate_one_qubit_rotation_with_parameter_assigned():
         "",
         "T  : |   0    |",
     )
-    expected = "\n".join(expected)
-    print(AsciiCircuitDiagram.build_diagram(new_circ))
-    assert AsciiCircuitDiagram.build_diagram(new_circ) == expected
+    _assert_correct_diagram(new_circ, expected)
 
 
 def test_qubit_width():
@@ -106,8 +99,7 @@ def test_qubit_width():
         "",
         "T    : |0|",
     )
-    expected = "\n".join(expected)
-    assert AsciiCircuitDiagram.build_diagram(circ) == expected
+    _assert_correct_diagram(circ, expected)
 
 
 def test_gate_width():
@@ -128,8 +120,7 @@ def test_gate_width():
         "",
         "T  : |0| 1 |",
     )
-    expected = "\n".join(expected)
-    assert AsciiCircuitDiagram.build_diagram(circ) == expected
+    _assert_correct_diagram(circ, expected)
 
 
 def test_time_width():
@@ -174,8 +165,7 @@ def test_time_width():
         "",
         "T   : |0|1|2|3|4|5|6|7|8|9|10|11|12|13|",
     )
-    expected = "\n".join(expected)
-    assert AsciiCircuitDiagram.build_diagram(circ) == expected
+    _assert_correct_diagram(circ, expected)
 
 
 def test_connector_across_two_qubits():
@@ -193,8 +183,7 @@ def test_connector_across_two_qubits():
         "",
         "T  : |0|1|",
     )
-    expected = "\n".join(expected)
-    assert AsciiCircuitDiagram.build_diagram(circ) == expected
+    _assert_correct_diagram(circ, expected)
 
 
 def test_overlapping_qubits():
@@ -212,8 +201,7 @@ def test_overlapping_qubits():
         "",
         "T  : | 0 |1|",
     )
-    expected = "\n".join(expected)
-    assert AsciiCircuitDiagram.build_diagram(circ) == expected
+    _assert_correct_diagram(circ, expected)
 
 
 def test_overlapping_qubits_angled_gates():
@@ -231,8 +219,7 @@ def test_overlapping_qubits_angled_gates():
         "",
         "T  : |    0     |1|",
     )
-    expected = "\n".join(expected)
-    assert AsciiCircuitDiagram.build_diagram(circ) == expected
+    _assert_correct_diagram(circ, expected)
 
 
 def test_connector_across_gt_two_qubits():
@@ -250,8 +237,7 @@ def test_connector_across_gt_two_qubits():
         "",
         "T  : | 0 |1|",
     )
-    expected = "\n".join(expected)
-    assert AsciiCircuitDiagram.build_diagram(circ) == expected
+    _assert_correct_diagram(circ, expected)
 
 
 def test_connector_across_non_used_qubits():
@@ -269,8 +255,7 @@ def test_connector_across_non_used_qubits():
         "",
         "T    : | 0 |1|",
     )
-    expected = "\n".join(expected)
-    assert AsciiCircuitDiagram.build_diagram(circ) == expected
+    _assert_correct_diagram(circ, expected)
 
 
 def test_verbatim_1q_no_preceding():
@@ -282,8 +267,7 @@ def test_verbatim_1q_no_preceding():
         "",
         "T  : |      0      |1|     2     |",
     )
-    expected = "\n".join(expected)
-    assert AsciiCircuitDiagram.build_diagram(circ) == expected
+    _assert_correct_diagram(circ, expected)
 
 
 def test_verbatim_1q_preceding():
@@ -295,8 +279,7 @@ def test_verbatim_1q_preceding():
         "",
         "T  : |0|      1      |2|     3     |",
     )
-    expected = "\n".join(expected)
-    assert AsciiCircuitDiagram.build_diagram(circ) == expected
+    _assert_correct_diagram(circ, expected)
 
 
 def test_verbatim_1q_following():
@@ -308,8 +291,7 @@ def test_verbatim_1q_following():
         "",
         "T  : |      0      |1|     2     |3|",
     )
-    expected = "\n".join(expected)
-    assert AsciiCircuitDiagram.build_diagram(circ) == expected
+    _assert_correct_diagram(circ, expected)
 
 
 def test_verbatim_2q_no_preceding():
@@ -323,8 +305,7 @@ def test_verbatim_2q_no_preceding():
         "",
         "T  : |      0      |1|2|     3     |",
     )
-    expected = "\n".join(expected)
-    assert AsciiCircuitDiagram.build_diagram(circ) == expected
+    _assert_correct_diagram(circ, expected)
 
 
 def test_verbatim_2q_preceding():
@@ -338,8 +319,7 @@ def test_verbatim_2q_preceding():
         "",
         "T  : |0|      1      |2|3|     4     |",
     )
-    expected = "\n".join(expected)
-    assert AsciiCircuitDiagram.build_diagram(circ) == expected
+    _assert_correct_diagram(circ, expected)
 
 
 def test_verbatim_2q_following():
@@ -353,8 +333,7 @@ def test_verbatim_2q_following():
         "",
         "T  : |      0      |1|2|     3     |4|",
     )
-    expected = "\n".join(expected)
-    assert AsciiCircuitDiagram.build_diagram(circ) == expected
+    _assert_correct_diagram(circ, expected)
 
 
 def test_verbatim_3q_no_preceding():
@@ -370,8 +349,7 @@ def test_verbatim_3q_no_preceding():
         "",
         "T  : |      0      |1|2|3|     4     |",
     )
-    expected = "\n".join(expected)
-    assert AsciiCircuitDiagram.build_diagram(circ) == expected
+    _assert_correct_diagram(circ, expected)
 
 
 def test_verbatim_3q_preceding():
@@ -387,8 +365,7 @@ def test_verbatim_3q_preceding():
         "",
         "T  : |0|      1      |2|3|4|     5     |",
     )
-    expected = "\n".join(expected)
-    assert AsciiCircuitDiagram.build_diagram(circ) == expected
+    _assert_correct_diagram(circ, expected)
 
 
 def test_verbatim_3q_following():
@@ -404,8 +381,7 @@ def test_verbatim_3q_following():
         "",
         "T  : |      0      |1|2|3|     4     |5|",
     )
-    expected = "\n".join(expected)
-    assert AsciiCircuitDiagram.build_diagram(circ) == expected
+    _assert_correct_diagram(circ, expected)
 
 
 def test_verbatim_different_qubits():
@@ -423,8 +399,7 @@ def test_verbatim_different_qubits():
         "",
         "T  : |0|      1      |2|     3     |4|",
     )
-    expected = "\n".join(expected)
-    assert AsciiCircuitDiagram.build_diagram(circ) == expected
+    _assert_correct_diagram(circ, expected)
 
 
 def test_verbatim_qubset_qubits():
@@ -442,8 +417,7 @@ def test_verbatim_qubset_qubits():
         "",
         "T  : |0|1|2|      3      |4|     5     |6|",
     )
-    expected = "\n".join(expected)
-    assert AsciiCircuitDiagram.build_diagram(circ) == expected
+    _assert_correct_diagram(circ, expected)
 
 
 def test_ignore_non_gates():
@@ -467,8 +441,7 @@ def test_ignore_non_gates():
         "",
         "T  : |0|1|",
     )
-    expected = "\n".join(expected)
-    assert AsciiCircuitDiagram.build_diagram(circ) == expected
+    _assert_correct_diagram(circ, expected)
 
 
 def test_result_types_target_none():
@@ -482,8 +455,7 @@ def test_result_types_target_none():
         "",
         "T    : |0|Result Types|",
     )
-    expected = "\n".join(expected)
-    assert AsciiCircuitDiagram.build_diagram(circ) == expected
+    _assert_correct_diagram(circ, expected)
 
 
 def test_result_types_target_some():
@@ -505,8 +477,7 @@ def test_result_types_target_some():
         "",
         "T    : |0|  Result Types  |",
     )
-    expected = "\n".join(expected)
-    assert AsciiCircuitDiagram.build_diagram(circ) == expected
+    _assert_correct_diagram(circ, expected)
 
 
 def test_additional_result_types():
@@ -524,8 +495,7 @@ def test_additional_result_types():
         "",
         "Additional result types: StateVector, Amplitude(110,001)",
     )
-    expected = "\n".join(expected)
-    assert AsciiCircuitDiagram.build_diagram(circ) == expected
+    _assert_correct_diagram(circ, expected)
 
 
 def test_multiple_result_types():
@@ -551,8 +521,7 @@ def test_multiple_result_types():
         "",
         "T  : | 0 |1|      Result Types      |",
     )
-    expected = "\n".join(expected)
-    assert AsciiCircuitDiagram.build_diagram(circ) == expected
+    _assert_correct_diagram(circ, expected)
 
 
 def test_multiple_result_types_with_state_vector_amplitude():
@@ -582,8 +551,7 @@ def test_multiple_result_types_with_state_vector_amplitude():
         "",
         "Additional result types: Amplitude(0001), StateVector",
     )
-    expected = "\n".join(expected)
-    assert AsciiCircuitDiagram.build_diagram(circ) == expected
+    _assert_correct_diagram(circ, expected)
 
 
 def test_multiple_result_types_with_custom_hermitian_ascii_symbol():
@@ -616,8 +584,7 @@ def test_multiple_result_types_with_custom_hermitian_ascii_symbol():
         "",
         "T  : | 0 |1|   Result Types    |",
     )
-    expected = "\n".join(expected)
-    assert AsciiCircuitDiagram.build_diagram(circ) == expected
+    _assert_correct_diagram(circ, expected)
 
 
 def test_noise_1qubit():
@@ -631,8 +598,7 @@ def test_noise_1qubit():
         "",
         "T  : |    0    |",
     )
-    expected = "\n".join(expected)
-    assert AsciiCircuitDiagram.build_diagram(circ) == expected
+    _assert_correct_diagram(circ, expected)
 
 
 def test_noise_2qubit():
@@ -648,5 +614,8 @@ def test_noise_2qubit():
         "",
         "T  : | 0  |",
     )
-    expected = "\n".join(expected)
-    assert AsciiCircuitDiagram.build_diagram(circ) == expected
+    _assert_correct_diagram(circ, expected)
+
+
+def _assert_correct_diagram(circ, expected):
+    assert AsciiCircuitDiagram.build_diagram(circ) == "\n".join(expected)
